@@ -7,6 +7,7 @@ from exabel_data_sdk.stubs.exabel.api.data.v1.all_pb2 import (
     ListSignalsRequest,
     ListSignalsResponse,
     Signal,
+    UpdateSignalRequest,
 )
 
 
@@ -29,5 +30,13 @@ class SignalHttpClient(SignalApiClient, BaseHttpClient):
             request.signal,
         )
 
+    def update_signal(self, request: UpdateSignalRequest) -> Signal:
+        return self._request(
+            "PATCH",
+            request.signal.name,
+            Signal(),
+            request.signal,
+        )
+
     def delete_signal(self, request: DeleteSignalRequest) -> None:
         self._request("DELETE", request.name, None)
