@@ -1,5 +1,7 @@
 from typing import Optional
 
+from google.protobuf.field_mask_pb2 import FieldMask
+
 from exabel_data_sdk.client.api.api_client.grpc.relationship_grpc_client import (
     RelationshipGrpcClient,
 )
@@ -20,6 +22,8 @@ from exabel_data_sdk.stubs.exabel.api.data.v1.all_pb2 import (
     GetRelationshipTypeRequest,
     ListRelationshipsRequest,
     ListRelationshipTypesRequest,
+    UpdateRelationshipRequest,
+    UpdateRelationshipTypeRequest,
 )
 
 
@@ -81,6 +85,24 @@ class RelationshipApi:
         )
         return RelationshipType.from_proto(response)
 
+    def update_relationship_type(
+        self, relationship_type: RelationshipType, update_mask: FieldMask = None
+    ) -> RelationshipType:
+        """
+        Update a relationship type.
+
+        Args:
+            relationship_type: The relationship type to update.
+            update_mask:       The fields to update. If not specified, the update behaves as a
+                               full update, overwriting all existing fields and properties.
+        """
+        response = self.client.update_relationship_type(
+            UpdateRelationshipTypeRequest(
+                relationship_type=relationship_type.to_proto(), update_mask=update_mask
+            )
+        )
+        return RelationshipType.from_proto(response)
+
     def delete_relationship_type(self, relationship_type: str) -> None:
         """
         Delete a relationship type.
@@ -200,6 +222,22 @@ class RelationshipApi:
         )
         return Relationship.from_proto(response)
 
+    def update_relationship(
+        self, relationship: Relationship, update_mask: FieldMask = None
+    ) -> Relationship:
+        """
+        Update a relationship between two entities.
+
+        Args:
+            relationship:  The relationship to update.
+            update_mask:   The fields to update. If not specified, the update behaves as a
+                           full update, overwriting all existing fields and properties.
+        """
+        response = self.client.update_relationship(
+            UpdateRelationshipRequest(relationship=relationship.to_proto(), update_mask=update_mask)
+        )
+        return Relationship.from_proto(response)
+
     def delete_relationship(self, relationship_type: str, from_entity: str, to_entity: str) -> None:
         """
         Delete a relationship.
